@@ -28,7 +28,8 @@ class SkyhubController:
         if response.status == 200:
             qty = produto.get("qty", 0)
             price = produto.get("price", 0)
-            return Produto(sku, price, qty)
+            promotional_price = produto.get("promotional_price", 0)
+            return Produto(sku, price, promotional_price, qty)
 
         elif response.status == 429:
             time.sleep(1)
@@ -54,9 +55,8 @@ class SkyhubController:
             return True
 
         if response.status == 429:
-            response = await self.request.request(
-                method="PUT", url=url, data=produtoJSON, headers=self.credentials
-            )
+            response = await self.atualiza_produto(produto)
+            return True
 
         else:
             logger.warning(f"O produto '{produto.sku}' não pode ser atualizado.")
